@@ -2,7 +2,7 @@
 #  __init__.py
 #  EnumeratorProject
 #
-__version__ = "v0.9"
+__version__ = "v1.0"
 
 import logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
@@ -11,6 +11,3 @@ from peppercornenumerator.enumerator import Enumerator, PolymerizationError
 from peppercornenumerator.enumerator import enumerate_pil, enumerate_ssw
 from peppercornenumerator.condense import CondensationError, PepperCondensation
 
-# Deprecated since v0.6
-from peppercornenumerator.condense import ReactionGraph
-
