@@ -2,9 +2,6 @@
 #  peppercornenumerator/reactions.py
 #  EnumeratorProject
 #
-from __future__ import absolute_import, print_function, division
-from builtins import map
-
 import logging
 log = logging.getLogger(__name__)
 
@@ -390,8 +387,7 @@ def bind21(reactant1, reactant2, max_helix = True, remote=None, pkwarning=False)
                     # Exclude the non-pseudoknotted interactions
                     continue
                 if (dom1.can_pair(dom2)):
-                    print("# WARNING: potential pk-interaction: {} and {}".format(
-                        reactant1, reactant2))
+                    log.warning("potential pk-interaction: {} and {}".format(reactant1, reactant2))
 
    
     output = set()
